@@ -4,7 +4,7 @@ BEGIN {
   $Dist::Zilla::MintingProfile::Author::Caelum::AUTHORITY = 'cpan:RKITOVER';
 }
 {
-  $Dist::Zilla::MintingProfile::Author::Caelum::VERSION = '0.05';
+  $Dist::Zilla::MintingProfile::Author::Caelum::VERSION = '0.06';
 }
 
 use strict;
@@ -15,6 +15,7 @@ use Moose;
 use Dist::Zilla::PluginBundle::AVAR ();
 use Dist::Zilla::Plugin::Git::Init ();
 use Dist::Zilla::Plugin::GitHub::Create 0.30 ();
+use Dist::Zilla::Plugin::Git::PushInitial ();
 
 with 'Dist::Zilla::Role::MintingProfile::ShareDir';
 
@@ -28,8 +29,6 @@ Dist::Zilla::MintingProfile::Author::Caelum - Basic Minting Profile for @AVAR
 
     dzil setup
 
-    git config --global push.default simple # if you have git >= 1.8
-
     git config --global github.user GitHubLoginName
     git config --global github.password GitHubPassword
 
@@ -39,8 +38,6 @@ Dist::Zilla::MintingProfile::Author::Caelum - Basic Minting Profile for @AVAR
 
     # edit stuff and commit
 
-    git push origin master -u # only for git < 1.8
-
     dzil release
 
 =head1 DESCRIPTION
